pub struct DesiredPool {Show 14 fields
pub pool_id: String,
pub flake_ref: String,
pub profile: String,
pub role: Role,
pub instance_resources: InstanceResources,
pub desired_counts: DesiredCounts,
pub runtime_policy: RuntimePolicy,
pub seccomp_policy: String,
pub snapshot_compression: String,
pub routing_table: Option<RoutingTable>,
pub secret_scopes: Vec<SecretScope>,
pub sleep_policy: Option<SleepPolicyConfig>,
pub default_update_strategy: Option<UpdateStrategy>,
pub registry_artifact: Option<RegistryArtifact>,
}Fields
pool_id: Stringflake_ref: Stringprofile: Stringrole: Roleinstance_resources: InstanceResourcesdesired_counts: DesiredCountsruntime_policy: RuntimePolicyseccomp_policy: Stringsnapshot_compression: Stringrouting_table: Option<RoutingTable>secret_scopes: Vec<SecretScope>sleep_policy: Option<SleepPolicyConfig>default_update_strategy: Option<UpdateStrategy>Default update strategy for rollouts (rolling or canary). When set, the agent uses this instead of the deploy config default.
registry_artifact: Option<RegistryArtifact>Pre-built artifacts to pull from the template registry. When set, the agent downloads artifacts from S3 instead of running a local Nix build. Falls back to local build if the pull fails.