Functions
- migrate
- Apply a chain of migrations to a raw JSON value.
- schema_
version_ of - Read the
schema_versionfield from a raw JSON object value. Returns 0 if the field is absent (pre-versioned files).
Type Aliases
- Migrate
Fn - A versioned migration function: takes a raw JSON value at schema version N and returns a transformed value at schema version N+1.