pub trait ShellEnvironment: Send + Sync {
// Required methods
fn shell_exec(&self, script: &str) -> Result<()>;
fn shell_exec_stdout(&self, script: &str) -> Result<String>;
fn shell_exec_visible(&self, script: &str) -> Result<()>;
fn log_info(&self, msg: &str);
fn log_success(&self, msg: &str);
// Provided method
fn log_warn(&self, _msg: &str) { ... }
}Expand description
Minimal shell execution abstraction used by dev-mode builds.
This trait provides just shell execution and logging — enough for
dev_build() which runs nix build directly in the Lima VM.
Required Methods
Sourcefn shell_exec(&self, script: &str) -> Result<()>
fn shell_exec(&self, script: &str) -> Result<()>
Execute a shell script in the VM.
Sourcefn shell_exec_stdout(&self, script: &str) -> Result<String>
fn shell_exec_stdout(&self, script: &str) -> Result<String>
Execute a shell script in the VM and capture stdout.
Sourcefn shell_exec_visible(&self, script: &str) -> Result<()>
fn shell_exec_visible(&self, script: &str) -> Result<()>
Execute a shell script with visible output.
Sourcefn log_success(&self, msg: &str)
fn log_success(&self, msg: &str)
Log a success message.