load

Function load 

pub fn load(override_dir: Option<&Path>) -> MvmConfig
Load MvmConfig from ~/.mvm/config.toml (or override_dir/config.toml in tests).

If the file does not exist, it is created with defaults. If it cannot be parsed, defaults are returned with a warning.